@@ -219,8 +219,6 @@ python/python3 -m domains_api --help''')
             setattr(self.user, 'previous_ip', self.current_ip)
             self.user.save_user()
             self.domains_api_call()
-        finally:
-            sys.exit()
 
     def domains_api_call(self):
 
